@@ -75,6 +75,8 @@ HEADER_ATTRS_2_2 = HEADER_ATTRS_2_1 + ( # PEP 643
     ('Dynamic', 'dynamic', True),
 )
 
+HEADER_ATTRS_2_3 = HEADER_ATTRS_2_2  # PEP 685
+
 HEADER_ATTRS = {
     '1.0': HEADER_ATTRS_1_0,
     '1.1': HEADER_ATTRS_1_1,
@@ -82,6 +84,7 @@ HEADER_ATTRS = {
     '2.0': HEADER_ATTRS_2_0,
     '2.1': HEADER_ATTRS_2_1,
     '2.2': HEADER_ATTRS_2_2,
+    '2.3': HEADER_ATTRS_2_3,
 }
 
 class Distribution(object):
